==> haskell-criterion-1.2.1.0-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.2.1.0
id: criterion-1.2.1.0-CuAu0oQqVQO7v66KlGPXbW
key: criterion-1.2.1.0-CuAu0oQqVQO7v66KlGPXbW
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
abi: 5e54230389716408a9fb593c81cd4164
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/criterion-1.2.1.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/criterion-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-criterion
hs-libraries: HScriterion-1.2.1.0-CuAu0oQqVQO7v66KlGPXbW
depends:
    Glob-0.7.14-9UgIHX1kslJ9qchuvR7jbv
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk
    ansi-wl-pprint-0.6.7.3-7jqnIfTUHr2Bkg0VIWs8Q5 base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22 binary-0.8.3.0
    bytestring-0.10.8.1 cassava-0.5.0.0-9eHP0K5GPX7LLp0v0Prrj1
    code-page-0.1.3-Fxfj8KlZt5M4CQMDwRDd5i containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd filepath-1.4.1.1
    js-flot-0.8.3-FFINNwUg9vmHMMWQsN8uhg
    js-jquery-3.2.1-GtxtZ651RlV17366fNzcXt
    microstache-1.0.1.1-LiPfeHlyxBP62bEWiTk9nk
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    mwc-random-0.13.6.0-K5ePRTjCwYQ3u7Qp4sh2LR
    optparse-applicative-0.13.2.0-ATtPSoVb5QO98rs9Fb1xKb
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    statistics-0.14.0.2-DwTksDozTf84s3a0u9j38y
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    vector-algorithms-0.7.0.1-CyLxDfJFRkcBZ53a4eh1Bl
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.2.2.0-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.2.2.0
id: criterion-1.2.2.0-FRWvG3QznYV8DUQ7VrQVOV
key: criterion-1.2.2.0-FRWvG3QznYV8DUQ7VrQVOV
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
abi: 3d3b28debadf25b297108455e1a9a58b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/criterion-1.2.2.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/criterion-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-criterion
hs-libraries: HScriterion-1.2.2.0-FRWvG3QznYV8DUQ7VrQVOV
depends:
    Glob-0.7.14-9UgIHX1kslJ9qchuvR7jbv
    aeson-1.1.2.0-8R262j8BseM7FTnCfGfbwu
    ansi-wl-pprint-0.6.8.1-E76ARGam2soH7nnUTX5qkH base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22 binary-0.8.3.0
    bytestring-0.10.8.1 cassava-0.5.0.0-995yOqa9hG8BH5dbXZLscZ
    code-page-0.1.3-Fxfj8KlZt5M4CQMDwRDd5i containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd filepath-1.4.1.1
    js-flot-0.8.3-FFINNwUg9vmHMMWQsN8uhg
    js-jquery-3.2.1-GtxtZ651RlV17366fNzcXt
    microstache-1.0.1.1-B8qiV6Q5qWvJimgkdpsnuJ
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    mwc-random-0.13.6.0-K5ePRTjCwYQ3u7Qp4sh2LR
    optparse-applicative-0.13.2.0-J9tSV1D1M11JWNEbVQPonU
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    statistics-0.14.0.2-ID4gcJhVC5PDCRHTtmfU30
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    vector-algorithms-0.7.0.1-CyLxDfJFRkcBZ53a4eh1Bl
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
